===
API
===

* **Methods** - official Crypto Pay API methods.
* **Types** - official Crypto Pay API types.
* **Enums** - enumerable parameter values of methods.
* **Network** - API networks.
* **Errors** - error models.

.. toctree::
    :maxdepth: 2

    methods
    types
    enums
    network
    errors